@@ -29,7 +29,8 @@ import re
 from os.path import exists
 from glob import glob
 
-import pwem
+from pwem.constants import ALIGN_2D
+from pwem.objects import SetOfClasses2D
 from pwem.protocols import ProtClassify2D
 from pyworkflow.protocol.params import (PointerParam, FloatParam, IntParam,
                                         EnumParam, StringParam,
@@ -551,7 +552,7 @@ class EmanProtRefine2D(ProtClassify2D):
                   'threads': self.numberOfThreads.get(),
                   'mpis': self.numberOfMpi.get(),
                   'scratch': SCRATCHDIR}
-        args = args % params
+        args %= params
 
         if self.extraParams.hasValue():
             args += " " + self.extraParams.get()
@@ -625,7 +626,7 @@ class EmanProtRefine2D(ProtClassify2D):
             cleanPath(data_classes)
 
         if not exists(data_classes):
-            clsSet = pwem.objects.SetOfClasses2D(filename=data_classes)
+            clsSet = SetOfClasses2D(filename=data_classes)
             clsSet.setImages(self._getInputParticles())
             self._fillClassesFromIter(clsSet, it)
             clsSet.write()
@@ -681,7 +682,7 @@ class EmanProtRefine2D(ProtClassify2D):
     def _updateParticle(self, item, row):
         if row[1] == 1:  # enabled
             item.setClassId(row[2] + 1)
-            item.setTransform(rowToAlignment(row[3:], pwem.constants.ALIGN_2D))
+            item.setTransform(rowToAlignment(row[3:], ALIGN_2D))
         else:
             setattr(item, "_appendItem", False)
 
